changeset 3:d05fadb1c7b5 draft

Uploaded v0.0.2
author peterjc
date Fri, 12 Apr 2013 06:34:51 -0400
parents d1a2d254fba2
children a9142939d718
files tools/fasta_tools/fasta_filter_by_id.py tools/fasta_tools/fasta_filter_by_id.txt tools/fasta_tools/fasta_filter_by_id.xml
diffstat 3 files changed, 7 insertions(+), 41 deletions(-) [+]
line wrap: on
line diff
--- a/tools/fasta_tools/fasta_filter_by_id.txt	Tue Jun 07 16:34:21 2011 -0400
+++ b/tools/fasta_tools/fasta_filter_by_id.txt	Fri Apr 12 06:34:51 2013 -0400
@@ -1,12 +1,3 @@
-Obsolete
-========
-
-This tool is now obsolete, having been replaced	by a more general version
-covering the FASTA, FASTQ and SFF sequence formats in a single tool. You
-should only install this tool if you need to support existing workflows
-which used it.
-
-
 Galaxy tool to filter FASTA sequences by ID
 ===========================================
 
@@ -23,7 +14,7 @@
 * fasta_filter_by_id.py (the Python script)
 * fasta_filter_by_id.xml (the Galaxy tool definition)
 
-The suggested location is next to the similarly named fasta_filter_by_length.py
+The suggested location is next to the similarly names fasta_filter_by_length.py
 and fasta_filter_by_length.xml files which are included with Galaxy, i.e.
 in the Galaxy folder tools/fasta_tools
 
@@ -39,19 +30,13 @@
 History
 =======
 
-v0.0.1 - Initial version (not publicly released)
+v0.0.1 - Initial verion (not publicly released)
 v0.0.2 - Allow both, just pos or just neg output files
-v0.0.3 - Include FASTA in tool name
-v0.0.4 - Deprecated, marked as hidden in the XML
-
 
 Developers
 ==========
 
-This script and related tools are being developed on the following hg branch:
-http://bitbucket.org/peterjc/galaxy-central/src/tools
-
-This incorporates the previously used hg branch:
+These wrappers are currently being developed on the following hg branch:
 http://bitbucket.org/peterjc/galaxy-central/src/fasta_filter
 
 For making the "Galaxy Tool Shed" http://community.g2.bx.psu.edu/ tarball use
--- a/tools/fasta_tools/fasta_filter_by_id.xml	Tue Jun 07 16:34:21 2011 -0400
+++ b/tools/fasta_tools/fasta_filter_by_id.xml	Fri Apr 12 06:34:51 2013 -0400
@@ -1,4 +1,4 @@
-<tool id="fasta_filter_by_id" name="Filter FASTA by ID" version="0.0.4" hidden="true">
+<tool id="fasta_filter_by_id" name="Filter sequences by ID" version="0.0.2">
 	<description>from a tabular file</description>
 	<command interpreter="python">
 fasta_filter_by_id.py $input_tabular $columns $input_fasta
@@ -64,12 +64,6 @@
 	</tests>
 	<help>
 
-**Deprecated**
-
-This tool is now obsolete, and should not be used in future. It has been
-replaced by a more general version covering FASTA, FASTQ and SFF in one
-single tool.
-
 **What it does**
 
 By default it divides a FASTA file in two, those sequences with or without an
@@ -79,12 +73,5 @@
 Note that the order of sequences in the original FASTA file is preserved.
 Also, if any sequences share an identifier, duplicates are not removed.
 
-**Example Usage**
-
-Given a FASTA file of proteins you might run a signal peptide search (e.g.
-via the SignalP wrapper for Galaxy), then filtered these tabular results to
-select just those with a signal peptide. You could then use this tool to get
-a FASTA file of only the proteins with predicted signal peptides.
-
 	</help>
 </tool>
--- a/tools/fasta_tools/fasta_filter_by_id.py	Tue Jun 07 16:34:21 2011 -0400
+++ b/tools/fasta_tools/fasta_filter_by_id.py	Fri Apr 12 06:34:51 2013 -0400
@@ -3,20 +3,14 @@
 
 Takes five command line options, tabular filename, ID column numbers
 (comma separated list using one based counting), input FASTA filename, and
-two output FASTA filenames (for records with and without the given IDs).
-
-If either output filename is just a minus sign, that file is not created.
+two output FASTA filenames (for records with and without any BLAST hits).
+If the either output filename is just a minus sign, that file is not created.
 This is intended to allow output for just the matched (or just the non-matched)
 records.
 
 Note in the default NCBI BLAST+ tabular output, the query sequence ID is
 in column one, and the ID of the match from the database is in column two.
 Here sensible values for the column numbers would therefore be "1" or "2".
-
-This script is copyright 2010 by Peter Cock, SCRI, UK. All rights reserved.
-See accompanying text file for licence details (MIT/BSD style).
-
-This is version 0.0.3 of the script.
 """
 import sys
 from galaxy_utils.sequence.fasta import fastaReader, fastaWriter
@@ -57,7 +51,7 @@
     print "Using %i IDs from tabular file" % (len(ids))
 handle.close()
 
 #Write filtered FASTA file based on IDs from tabular file
 reader = fastaReader(open(in_file, "rU"))
 if out_positive_file != "-" and out_negative_file != "-":
     print "Generating two FASTA files"
@@ -57,7 +51,7 @@
 handle.close()
 
-#Write filtered FASTA file based on IDs from tabular file
+#Write filtered FASTA file based on IDs from BLAST file
 reader = fastaReader(open(in_file, "rU"))
 if out_positive_file != "-" and out_negative_file != "-":